darkhistory.electrons.ics.ics_spectrum.ics_spec — DarkHistory documentation

# darkhistory.electrons.ics.ics_spectrum.ics_spec

`darkhistory.electrons.ics.ics_spectrum.` `ics_spec`(eleckineng, photeng, T, as_pairs=False, inf_upp_bound=True, thomson_tf=None, rel_tf=None, T_ref=None)

  ICS spectrum of secondary photons.

  Switches between thomson_spec and rel_spec.

  Parameters: | eleckineng : ndarray Incoming electron energy. photeng : ndarray Outgoing photon energy. T : float CMB temperature. as_pairs : bool, optional If True, treats eleckineng and photeng as a paired list: produces eleckineng.size == photeng.size values. Otherwise, gets the spectrum at each photeng for each eleckineng, returning an array of length eleckineng.size*photeng.size. inf_upp_bound : bool If True, calculates the approximate relativistic spectrum that is used for fast interpolation over different values of T. See Notes for more details. Default is True. thomson_tf : TransFuncAtRedshift, optional Reference Thomson ICS transfer function. If specified, calculation is done by interpolating over the transfer function. rel_tf : TransFuncAtRedshift, optional Reference relativistic ICS transfer function. If specified, calculation is done by interpolating over the transfer function. T_ref : float, optional The reference temperature at which the reference transfer functions is evaluated. If not specified, defaults to phys.TCMB(400).
  Returns: | TransFuncAtRedshift dN/(dt dE) of the outgoing photons, dt = 1 s, with self.in_eng = eleckineng and self.eng = photeng. self.rs is determined from T, and self.dlnz is normalized to 1 second.

  Notes

  Insert note on the suitability of the method.

#### Previous topic

darkhistory.electrons.ics.ics_spectrum

#### Next topic

darkhistory.electrons.ics.ics_spectrum.thomson_spec_series

### This Page

Show Source